==> vegastrike_0.4.1.orig.tar.gz: vegastrike-0.4.1/src/boost129/boost/test/included/unit_test_framework.hpp <==
//  (C) Copyright Gennadiy Rozental 2001-2002.
//  Permission to copy, use, modify, sell and distribute this software
//  is granted provided this copyright notice appears in all copies.
//  This software is provided "as is" without express or implied warranty,
//  and with no claim as to its suitability for any purpose.

//  See http://www.boost.org for most recent version including documentation.
//
//  File        : $RCSfile: unit_test_framework.hpp,v $
//
//  Version     : $Id: unit_test_framework.hpp,v 1.1.1.1 2002/12/15 09:04:21 hellcatv Exp $
//
//  Description : included (vs. linked ) version of Unit Test Framework
// ***************************************************************************

#ifndef BOOST_INCLUDED_UNIT_TEST_FRAMEWORK_HPP
#define BOOST_INCLUDED_UNIT_TEST_FRAMEWORK_HPP

#include <libs/test/src/execution_monitor.cpp>

#include <libs/test/src/test_tools.cpp>

#include <libs/test/src/unit_test_result.cpp>
#include <libs/test/src/unit_test_suite.cpp>
#include <libs/test/src/unit_test_parameters.cpp>
#include <libs/test/src/unit_test_log.cpp>
#include <libs/test/src/unit_test_monitor.cpp>

#include <libs/test/src/unit_test_main.cpp>

// ***************************************************************************
//  Revision History :
//  
//  $Log: unit_test_framework.hpp,v $
//  Revision 1.1.1.1  2002/12/15 09:04:21  hellcatv
//  importing the boost stuffs
//
//  Revision 1.1  2002/08/26 09:09:00  rogeeff
//  Initial commit
//

// ***************************************************************************

#endif // BOOST_INCLUDED_UNIT_TEST_FRAMEWORK_HPP

==> vegastrike_0.4.2.orig.tar.gz: vegastrike-0.4.2/src/boost129/boost/test/included/unit_test_framework.hpp <==
//  (C) Copyright Gennadiy Rozental 2001-2003.
//  Use, modification, and distribution are subject to the 
//  Boost Software License, Version 1.0. (See accompanying file 
//  LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)

//  See http://www.boost.org/libs/test for the library home page.
//
//  File        : $RCSfile: unit_test_framework.hpp,v $
//
//  Version     : $Revision: 1.2 $
//
//  Description : included (vs. linked ) version of Unit Test Framework
// ***************************************************************************

#ifndef BOOST_INCLUDED_UNIT_TEST_FRAMEWORK_HPP
#define BOOST_INCLUDED_UNIT_TEST_FRAMEWORK_HPP

#include <libs/test/src/execution_monitor.cpp>

#include <libs/test/src/test_tools.cpp>

#include <libs/test/src/unit_test_result.cpp>
#include <libs/test/src/unit_test_suite.cpp>
#include <libs/test/src/unit_test_parameters.cpp>
#include <libs/test/src/unit_test_log.cpp>
#include <libs/test/src/unit_test_monitor.cpp>
#include <libs/test/src/supplied_log_formatters.cpp>

#include <libs/test/src/unit_test_main.cpp>

// ***************************************************************************
//  Revision History :
//  
//  $Log: unit_test_framework.hpp,v $
//  Revision 1.2  2004/04/25 07:46:54  hellcatv
//  *** empty log message ***
//
//  Revision 1.6  2003/12/01 00:41:56  rogeeff
//  prerelease cleaning
//

// ***************************************************************************

#endif // BOOST_INCLUDED_UNIT_TEST_FRAMEWORK_HPP
